@@ -13,12 +13,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from google.cloud.contact_center_insights import gapic_version as package_version
+
+__version__ = package_version.__version__
+
 
 from .services.contact_center_insights import (
     ContactCenterInsightsAsyncClient,
     ContactCenterInsightsClient,
 )
 from .types.contact_center_insights import (
+    BulkAnalyzeConversationsMetadata,
+    BulkAnalyzeConversationsRequest,
+    BulkAnalyzeConversationsResponse,
     CalculateIssueModelStatsRequest,
     CalculateIssueModelStatsResponse,
     CalculateStatsRequest,
@@ -35,6 +42,7 @@ from .types.contact_center_insights import (
     DeleteConversationRequest,
     DeleteIssueModelMetadata,
     DeleteIssueModelRequest,
+    DeleteIssueRequest,
     DeletePhraseMatcherRequest,
     DeleteViewRequest,
     DeployIssueModelMetadata,
@@ -50,6 +58,9 @@ from .types.contact_center_insights import (
     GetPhraseMatcherRequest,
     GetSettingsRequest,
     GetViewRequest,
+    IngestConversationsMetadata,
+    IngestConversationsRequest,
+    IngestConversationsResponse,
     ListAnalysesRequest,
     ListAnalysesResponse,
     ListConversationsRequest,
@@ -76,6 +87,7 @@ from .types.resources import (
     Analysis,
     AnalysisResult,
     AnnotationBoundary,
+    AnnotatorSelector,
     AnswerFeedback,
     ArticleSuggestionData,
     CallAnnotation,
@@ -97,6 +109,7 @@ from .types.resources import (
     InterruptionData,
     Issue,
     IssueAssignment,
+    IssueMatchData,
     IssueModel,
     IssueModelLabelStats,
     IssueModelResult,
@@ -119,8 +132,12 @@ __all__ = (
     "Analysis",
     "AnalysisResult",
     "AnnotationBoundary",
+    "AnnotatorSelector",
     "AnswerFeedback",
     "ArticleSuggestionData",
+    "BulkAnalyzeConversationsMetadata",
+    "BulkAnalyzeConversationsRequest",
+    "BulkAnalyzeConversationsResponse",
     "CalculateIssueModelStatsRequest",
     "CalculateIssueModelStatsResponse",
     "CalculateStatsRequest",
@@ -143,6 +160,7 @@ __all__ = (
     "DeleteConversationRequest",
     "DeleteIssueModelMetadata",
     "DeleteIssueModelRequest",
+    "DeleteIssueRequest",
     "DeletePhraseMatcherRequest",
     "DeleteViewRequest",
     "DeployIssueModelMetadata",
@@ -167,11 +185,15 @@ __all__ = (
     "GetSettingsRequest",
     "GetViewRequest",
     "HoldData",
+    "IngestConversationsMetadata",
+    "IngestConversationsRequest",
+    "IngestConversationsResponse",
     "Intent",
     "IntentMatchData",
     "InterruptionData",
     "Issue",
     "IssueAssignment",
+    "IssueMatchData",
     "IssueModel",
     "IssueModelLabelStats",
     "IssueModelResult",
